#
# spec file for package python-requirements-parser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-requirements-parser
Version:        0.6.0
Release:        1.4
Summary:        Pip requirement file parser
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/davidfischer/requirements-parser
Source:         https://github.com/davidfischer/requirements-parser/archive/v%{version}.tar.gz#/requirements-parser-%{version}.tar.gz
Patch1:         dont-install-readme.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
BuildArch:      noarch
%python_subpackages

%description
A Pip requirement file parser.

%prep
%autosetup -p1 -n requirements-parser-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.md
%{python_sitelib}/requirements
%{python_sitelib}/requirements_parser-%{version}.dist-info

%changelog
* Thu Mar 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * feat: upgrade CI workflows to get them running again
  * ci: update actions to latest for all workflows
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Support all documented options in requirements files #62
  * Library is now typed according to PEP561 (`0e1bb6a`)
  * Readthedocs config (`ac1e7fb`)
  * Added some typing (`169ff6e`)
  * Removed Python 2 code (`82f9473`)
  * Removed version from __init__ (`4e83b9d`)
- drop
  0001-Dont-fail-with-valid-options-in-requirements_txt-files.patch,
  remove-nose.patch: upstream
- add dont-install-readme.patch
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Sep 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add remove-nose.patch:
  * Use pytest, rather than nose.
* Wed Apr 15 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to not fail parsing requirements files with valid
  options like --only-binary or --trusted-host:
  * 0001-Dont-fail-with-valid-options-in-requirements_txt-files.patch
* Thu Dec 12 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Mon May 20 2019 pgajdos@suse.com
- version update to 0.2.0
  * Support multiple hashing algorithms at the end of the URL (#24)
  * Preserve login info in requirement URI (#33)
  * Support subdirectory fragments (#32)
  * Support version control URLs with extras (#30)
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 0.1.0:
  * Fix a bug involving parsing projects with underscores (#17)
  * Parse recursive requirements (#19)
* Thu Mar  6 2014 cfarrell@suse.com
- license update: BSD-2-Clause
  See License.rst
* Wed Sep  4 2013 speilicke@suse.com
- Initial version
